@@ -5,7 +5,7 @@ $self = {
                       'Cairo',
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/cairo -I/usr/include/freetype2 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/libpng16',
+          'inc' => '-I/usr/include/cairo -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include',
           'libs' => '-lcairo-gobject -l:libcairo.dll.a -lgobject-2.0 -lglib-2.0 -lintl',
           'typemaps' => []
         };
